@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE RecordWildCards #-}
 module Test.Mockery.Logging (
   captureLogMessages
@@ -6,11 +5,10 @@ module Test.Mockery.Logging (
 , LogLevel(..)
 ) where
 
-#if !MIN_VERSION_base(4,8,0)
-import           Control.Applicative
-#endif
 import           Control.Exception
-import           Data.IORef
+import           Data.IORef.Compat
+import           Prelude ()
+import           Prelude.Compat
 import           System.Logging.Facade.Types
 import           System.Logging.Facade.Sink
 
